Module: ResilientCall::Mixin

Defined in:
lib/resilient_call/mixin.rb

Overview

Adds the ‘resilient_method` class macro to any class that includes it, wrapping the named instance method in a transparent ResilientCall.call.

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Class Method Details

.included(base) ⇒ Object



7
8
9
# File 'lib/resilient_call/mixin.rb', line 7

def self.included(base)
  base.extend(ClassMethods)
end